# -*- coding: utf-8 -*-
from zope import schema
from zope.interface import implementer

from plone.autoform.directives import order_after, omitted

from Products.Poi import PoiMessageFactory as _
from Products.Poi.content.tracker import possibleAssignees
from Products.Poi.content.issue import IIssue as IIssueOrig
from Products.Poi.content.issue import Issue as IssueOrig


complexity_options = ("High", "Medium", "Low",)

class IIssue(IIssueOrig):
    """Customization of marker interface for Poi issue"""

    assignee = schema.Choice(
        title=_(u'Poi_label_issue_assignee', default=u'Ticket owner'),
        description=_(u'Poi_help_issue_assignee',
                      default=u"Select the user responsible "
                      u"for issue management."),
        source=possibleAssignees,
        required=False,
    )

    complexity = schema.Choice(
        title=_(u'Poi_label_issue_complexity', default=u'Complexity'),
        values=complexity_options,
        required=False,
    )

    software_engineer_time_total = schema.Float(
        title=_(u'Poi_label_software_engineer_time_total', default=u"Software Engineer Total Time"),
        description=_(u'Poi_help_software_engineer_time_total',
                      default=u"The total number of hours entered in responses."),
        required=False,
    )

    business_analyst_time_total = schema.Float(
        title=_(u'Poi_label_business_analyst_time_total', default=u"Business Analyst Total Time"),
        description=_(u'Poi_help_business_analyst_time_total',
                      default=u"The total number of hours entered in responses."),
        required=False,
    )

    transend_edi_support_time_total = schema.Float(
        title=_(u'Poi_label_transend_edi_support_time_total', default=u"TranSend/EDI Support Total Time"),
        description=_(u'Poi_help_transend_edi_support_time_total',
                      default=u"The total number of hours entered in responses."),
        required=False,
    )

    system_engineer_time_total = schema.Float(
        title=_(u'Poi_label_system_engineer_time_total',
                default=u"System Engineer Total Time"),
        description=_(u'Poi_help_system_engineer_time_total',
                      default=(u"The total number of hours entered "
                               u"in responses.")),
        required=False,
    )

    operations_roi_time = schema.Float(
        title=_(u'Poi_label_operations_roi_time',
                default=u"Operations ROI Time"),
        description=_(u'Poi_help_operations_roi_time',
                      default=(u"The number of hours for operations ROI.")),
        required=False,
    )

    # order things the way we want them
    order_after(subject='IRequestedBy.requested_by')
    order_after(watchers='IRequestedBy.requested_by')
    order_after(assignee='IRequestedBy.requested_by')
    order_after(contact_email='related_issue')
    order_after(complexity='related_issue')
    order_after(target_release='related_issue')
    order_after(severity='related_issue')
    order_after(issue_type='related_issue')
    order_after(area='related_issue')
    omitted('software_engineer_time_total')
    omitted('business_analyst_time_total')
    omitted('transend_edi_support_time_total')
    omitted('system_engineer_time_total')
    omitted('operations_roi_time')


@implementer(IIssue)
class Issue(IssueOrig):
    """
    An issue in the Poi Tracker
    """
    complexity_options = complexity_options
